@@ -1,12 +1,12 @@
 import os
 import sys
 from distutils import sysconfig
+import site
 
 NON_USERDEFINED_PATHES = [
     sysconfig.get_python_lib(standard_lib=True, prefix=os.path.realpath(sys.prefix)),
     sysconfig.get_python_lib(standard_lib=True),
-    sysconfig.get_python_lib(standard_lib=False)
-]
+] ++ site.getsitepackages()
 
 def dumps(m):
     return m.__name__
